@@ -646,7 +646,7 @@ mod impls {
                 }
                 Type::Amount => {
                     let n = Amount::deserial(source)?;
-                    Ok(Value::String(n.micro_gtu.to_string()))
+                    Ok(Value::String(n.micro_ccd.to_string()))
                 }
                 Type::AccountAddress => {
                     let address = AccountAddress::deserial(source)?;
